Chunker constructor

const Chunker({
  1. int chunkSize = 300,
})

Creates a new Chunker with the specified chunk size.

@param chunkSize The target size for each chunk in characters (default: 500)

Implementation

const Chunker({this.chunkSize = 300});