transformWithOverlap method
Transforms a text stream into chunks with overlap between consecutive chunks.
@param rawFeed The input stream of text @param overlap The number of characters to overlap between chunks (default: 125) @return A stream of chunks with overlapping content
Implementation
Stream<Chunk> transformWithOverlap(
Stream<String> rawFeed, {
int overlap = 50,
}) => transform(rawFeed).overlap(overlap);